==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/msk/kotlin/inputs/ClusterOpenMonitoringPrometheusJmxExporterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.msk.kotlin.inputs

import com.pulumi.aws.msk.inputs.ClusterOpenMonitoringPrometheusJmxExporterArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property enabledInBroker Indicates whether you want to enable or disable the Node Exporter.
 */
public data class ClusterOpenMonitoringPrometheusJmxExporterArgs(
    public val enabledInBroker: Output<Boolean>,
) : ConvertibleToJava<com.pulumi.aws.msk.inputs.ClusterOpenMonitoringPrometheusJmxExporterArgs> {
    override fun toJava(): com.pulumi.aws.msk.inputs.ClusterOpenMonitoringPrometheusJmxExporterArgs =
        com.pulumi.aws.msk.inputs.ClusterOpenMonitoringPrometheusJmxExporterArgs.builder()
            .enabledInBroker(enabledInBroker.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ClusterOpenMonitoringPrometheusJmxExporterArgs].
 */
@PulumiTagMarker
public class ClusterOpenMonitoringPrometheusJmxExporterArgsBuilder internal constructor() {
    private var enabledInBroker: Output<Boolean>? = null

    /**
     * @param value Indicates whether you want to enable or disable the Node Exporter.
     */
    @JvmName("gbnnvbiftmyvkxan")
    public suspend fun enabledInBroker(`value`: Output<Boolean>) {
        this.enabledInBroker = value
    }

    /**
     * @param value Indicates whether you want to enable or disable the Node Exporter.
     */
    @JvmName("mxujkkajjauldapd")
    public suspend fun enabledInBroker(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.enabledInBroker = mapped
    }

    internal fun build(): ClusterOpenMonitoringPrometheusJmxExporterArgs =
        ClusterOpenMonitoringPrometheusJmxExporterArgs(
            enabledInBroker = enabledInBroker ?: throw PulumiNullFieldException("enabledInBroker"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/msk/kotlin/inputs/ClusterOpenMonitoringPrometheusJmxExporterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.msk.kotlin.inputs

import com.pulumi.aws.msk.inputs.ClusterOpenMonitoringPrometheusJmxExporterArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property enabledInBroker Indicates whether you want to enable or disable the Node Exporter.
 */
public data class ClusterOpenMonitoringPrometheusJmxExporterArgs(
    public val enabledInBroker: Output<Boolean>,
) : ConvertibleToJava<com.pulumi.aws.msk.inputs.ClusterOpenMonitoringPrometheusJmxExporterArgs> {
    override fun toJava(): com.pulumi.aws.msk.inputs.ClusterOpenMonitoringPrometheusJmxExporterArgs =
        com.pulumi.aws.msk.inputs.ClusterOpenMonitoringPrometheusJmxExporterArgs.builder()
            .enabledInBroker(enabledInBroker.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ClusterOpenMonitoringPrometheusJmxExporterArgs].
 */
@PulumiTagMarker
public class ClusterOpenMonitoringPrometheusJmxExporterArgsBuilder internal constructor() {
    private var enabledInBroker: Output<Boolean>? = null

    /**
     * @param value Indicates whether you want to enable or disable the Node Exporter.
     */
    @JvmName("hctsejfvbugwqoxr")
    public suspend fun enabledInBroker(`value`: Output<Boolean>) {
        this.enabledInBroker = value
    }

    /**
     * @param value Indicates whether you want to enable or disable the Node Exporter.
     */
    @JvmName("upyooiltrvxdcuds")
    public suspend fun enabledInBroker(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.enabledInBroker = mapped
    }

    internal fun build(): ClusterOpenMonitoringPrometheusJmxExporterArgs =
        ClusterOpenMonitoringPrometheusJmxExporterArgs(
            enabledInBroker = enabledInBroker ?: throw PulumiNullFieldException("enabledInBroker"),
        )
}
